==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/Input/mpc/translations/mpc_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="59"/>
        <source>Musepack Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="61"/>
        <source>Musepack Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="121"/>
        <source>About Musepack Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="122"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Input/mpc/translations/mpc_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="59"/>
        <source>Musepack Plugin</source>
        <translation>Wtyczka Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="61"/>
        <source>Musepack Files</source>
        <translation>Pliki Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="121"/>
        <source>About Musepack Audio Plugin</source>
        <translation>O wtyczce Musepack Audio</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="122"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Wtyczka Musepack Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation></translation>
    </message>
</context>
</TS>
